%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Task Force on Modern Heuristic Optimization Test Beds
% Working Group on Modern Heuristic Optimization
% Intelligent Systems Subcommittee
% Power System Analysis, Computing, and Economic Committee
%
% 2017 Competition
% Evaluating the Performance of Modern Heuristic Optimizers on Smart Grid Operation Problems
% 
% 
% Test bed 1:
% Stochastic OPF based active-reactive power dispatch 
%
% Sergio Rivera (E-Mail: srriverar@unal.edu.co)
%
% For cases 2 and 5, it is considered that the 2 renewable generators are wind 
% generators and other solar generator. It is well known that in several parts 
% of the world the solar irradiance probability distribution follows a lognormal
% distribution. Additionally, there is a relation between the solar irradiance
% and the available real power. In this way, it is possible to get the probability 
% distribution of the available real power. The file named SolarWindStochastic.m 
% has the mentioned process in order to get the 5000 montecarlo scenarios for the 
% available real power. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% WIND PARAMETERS
%% Inicializacion de Constantes Eolico

                    Vi=5;           % velocidad de viento arranque (m/s)
                    Vr=15;          % Velocidad de viento nominal  (m/s)
                    Vo=45;          % Velocidad de viento parada   (m/s)
                    Wr=150;         % Potencia nominal aerogenador (Mw)
                    a= 15;          % Coeficiente lineal aerogenrador
                    b= -75;         % Coeficiente lineal.
                    sg= 15.9577;    % Parametro de escala distribucin Rayleigh.
                    c=sqrt(2)*sg;   % factor de escala Weilbull
                    k= 2;           % Factor de forma Weilbull
                   
%% SOLAR PARAMETERS                    
%% Inicializacion de Constantes Solar

Psr= 100; % [MW] Equivalent rated power output of the PV generator
Gstd= 775; %[W/m2] Solar irradiation in the standard enviroment
Rc=116; % [W/m2] A certain irradiation 
Wmax= 150;% 
lambda= 6; % 
beta= 0.25;% desviacin estandard
mu=lambda; % Solo para fines de simular 
sigma=beta;% Sola para fines de simular 

%% MONTECARLO SCENARIOS GENERATION
                    
                    N=5000;         % Numero de pruebas
         
for hi=1:N
                        v2(hi)=wblrnd(c,k); %% generacion viento 2
                        %v4(hi)=wblrnd(c,k); %% generacion viento 4
                        G(hi)=lognrnd(mu,sigma); %% generacion solar 4
                        v6(hi)=wblrnd(c,k); %% generacion viento 6

                        if (v2(hi)<Vi)||(v2(hi)>Vo)%% calculo de potencia eolica 2
                            W2(hi)=0;
                        elseif v2(hi)<Vr && Vi<v2(hi)
                            W2(hi)=a*v2(hi)+b;
                        else
                            W2(hi)=Wr;
                        end

                        if ((G(hi)<Rc)&&(G(hi)>0))%% calculo de potencia eolica
                                W4(hi)=Psr*(G(hi)^2/(Gstd*Rc));%Hay una corte W(i) maximo dado cuando G(i)=Rc
                        elseif G(hi)>Rc
                                W4(hi)=Psr*(G(hi)/Gstd);
                        end

                        if (v6(hi)<Vi)||(v6(hi)>Vo)%% calculo de potencia eolica 6
                            W6(hi)=0;
                        elseif v6(hi)<Vr && Vi<v6(hi)
                            W6(hi)=a*v6(hi)+b;
                        else
                            W6(hi)=Wr;
                        end
end

   global ScenarioType
    
   ScenarioType=5;


   figure(1)
   subplot(2,1,1)
   hist(v2)
   xlabel('wind speed (m/s) for wind generator at bus 2')
   ylabel('frequency')
   subplot(2,1,2)
   hist(W2)
   xlabel('available real power (MW) for wind generator at bus 2')
   ylabel('frequency')
 
   figure(2)
   subplot(2,1,1)
   hist(G)
   xlabel('solar irradiance (W/m^2) for solar generator at bus 6')
   ylabel('frequency')
   subplot(2,1,2)
   hist(W4)
   xlabel('available real power (MW) for solar generator at bus 6')
   ylabel('frequency')
   
   figure(3)
   subplot(2,1,1)
   hist(v6)
   xlabel('wind speed (m/s) for wind generator at bus 9')
   ylabel('frequency')
   subplot(2,1,2)
   hist(W6)
   xlabel('available real power (MW) for wind generator at bus 9')
   ylabel('frequency')

