%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Task Force on Modern Heuristic Optimization Test Beds
% Working Group on Modern Heuristic Optimization
% Intelligent Systems Subcommittee
% Power System Analysis, Computing, and Economic Committee
%
% 2017 Competition
% Evaluating the Performance of Modern Heuristic Optimizers on Smart Grid Operation Problems
% 
% Test bed 1:
% Stochastic OPF based active-reactive power dispatch 
% 
% Modified by Sergio Rivera (E-Mail: srriverar@unal.edu.co)
%
% from 2014 contest:
% Application of Modern Heuristic Optimization Algorithms 
% for Solving Optimal Power Flow Problems
% by
% Sebastian Wildenhues (E-Mail: sebastian.wildenhues@uni-due.de)
% 14th February 2014
%
%
%
% Employing MATPOWER as underlying power flow and basic Particle Swarm  
% Evoluation (PSO) algorithm as optimization engine, you can use the 
% test bed declarations as the template shown below.
%
% Results will be buffered and agglomerated automatically for storage to 
% formatted ASCII-files. Refer to problem definitions and implementation 
% guidelines for details.
%
% Note:
% This implementation has been tested using various MATLAB versions and
% hardware platforms. Feel free to contact us in case of incompatibilities.
% A MATPOWER installation must be on the MATLAB search path.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all
clear all
clc
global proc
global ps
global mpc
global res

global W2
global W4
global W6

algorithm_name='mvmopt';
algorithm_hd=str2func(algorithm_name);
test_bed_OPF_hd=str2func('test_bed_OPF');
system=57; % please note that the system only can be 57, 
           % the 2017 Stochastic OPF Competition only apply for this system
pop_size=1;
run_in_parallel=0; % please note that the parallel run functionallity is not
                   % valid for the 2017 Stochastic OPF Competition
show_lf_info=0;
refresh=500;
      
args{1}=system;
args{2}=show_lf_info;
args{3}=pop_size;
args{4}=refresh;
args{5}=algorithm_name;
args{6}=run_in_parallel;
args{7}=[];
args{8}=[];

%%CASES (to run the wanted cases please uncomment the respective line)
% 1
 load('WindPowerScenarios.mat')
% 2
% load('WindSolarPowerScenarios.mat')
% 3
% load('WindSolarHydroPowerScenarios.mat')
% 4
% WindStochastic
% 5
% SolarWindStochastic
% 6
% SolarWindHydroStochastic

%global ScenarioType
        
fprintf('Case_ %d \n', ScenarioType)

i=1; % please note that i must be 1, since it is only considered the Cost 
     % optimization not the losses
stop_test_case=0;

if i==1 & system==57
    
        while ~stop_test_case
            i=i+1;
            j=0;
            stop_scenario=0;
            while ~stop_scenario
                j=j+1;
                [stop_test_case,stop_scenario,err,obs]=test_bed_OPF_hd(i,j,1,args);
                args{7}=stop_test_case;
                args{8}=stop_scenario;
                if ~err
                    proc.n_run=1;
                    Runed=proc.n_run;
                    for k=1:proc.n_run  
                        test_bed_OPF_hd(i,j,k,args);
                        feval(algorithm_hd,test_bed_OPF_hd,i,j,k,args);
                        fprintf('Run %d finished.\n',k);
                    end
                    if Runed ~=31
                        fprintf('Please note that you did not run the required 31 runs\n');
                        fprintf('Please note that there will be not zip file, only the 5 output files\n');
                        fprintf('mentioned in the guide for each run\n');
                    else
                        test_bed_OPF_hd(i,j,987,args);
                    end
                end
            end
        end

else
    
    display('The 2017 competition only apply for the 57 buses system and OARPD')

end



